[PHP-CVS] svn: /php/php-src/ branches/PHP_5_3/NEWS branches/PHP_5_3/ext/zip/php_zip.c trunk/ext/zip/php_zip.c

2011-01-27 Thread Pierre Joye
pajoye   Thu, 27 Jan 2011 11:47:24 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307778

Log:
- Fix bug #53166,  missing parameters in reflections/docs

Bug: http://bugs.php.net/53166 (Assigned) ZipArchive::addFile() is missing 
parameters in docs
  
Changed paths:
U   php/php-src/branches/PHP_5_3/NEWS
U   php/php-src/branches/PHP_5_3/ext/zip/php_zip.c
U   php/php-src/trunk/ext/zip/php_zip.c

Modified: php/php-src/branches/PHP_5_3/NEWS
===
--- php/php-src/branches/PHP_5_3/NEWS	2011-01-27 09:57:01 UTC (rev 30)
+++ php/php-src/branches/PHP_5_3/NEWS	2011-01-27 11:47:24 UTC (rev 307778)
@@ -144,6 +144,8 @@
 (Hannes)
   . Fixed bug #53603 (ZipArchive should quiet stat errors). (brad dot froehle at
 gmail dot com, Gustavo)
+  . Fixed bzg #53166 (Missing parameters in docs and reflection definition).
+(Richard)

 06 Jan 2011, PHP 5.3.5
 - Fixed Bug #53632 (infinite loop with x87 fpu). (CVE-2010-4645) (Scott,

Modified: php/php-src/branches/PHP_5_3/ext/zip/php_zip.c
===
-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[PHP-CVS] svn: /php/php-src/trunk/ NEWS ext/pgsql/pgsql.c

2011-01-27 Thread Ilia Alshanetsky
iliaaThu, 27 Jan 2011 16:02:30 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307797

Log:
Added support for extra parameter for PGNotify().

Changed paths:
U   php/php-src/trunk/NEWS
U   php/php-src/trunk/ext/pgsql/pgsql.c

Modified: php/php-src/trunk/NEWS
===
--- php/php-src/trunk/NEWS  2011-01-27 15:37:38 UTC (rev 307796)
+++ php/php-src/trunk/NEWS  2011-01-27 16:02:30 UTC (rev 307797)
@@ -174,6 +174,10 @@
   . Added nextRowset support.
   . Fixed bug #50755 (PDO DBLIB Fails with OOM).

+- Improved PostgreSQL extension:
+  . Added support for extra parameter for PGNotify().
+(r dot i dot k at free dot fr, Ilia)
+
 - Improved Reflection extension: (Johannes)
   . Added ReflectionExtension::isTemporary() and
 ReflectionExtension::isPersistent() methods.

Modified: php/php-src/trunk/ext/pgsql/pgsql.c
===
--- php/php-src/trunk/ext/pgsql/pgsql.c 2011-01-27 15:37:38 UTC (rev 307796)
+++ php/php-src/trunk/ext/pgsql/pgsql.c 2011-01-27 16:02:30 UTC (rev 307797)
@@ -4782,10 +4782,24 @@
if (result_type  PGSQL_NUM) {
add_index_string(return_value, 0, pgsql_notify-relname, 1);
add_index_long(return_value, 1, pgsql_notify-be_pid);
+#if HAVE_PQPROTOCOLVERSION  HAVE_PQPARAMETERSTATUS
+   if (PQprotocolVersion(pgsql) = 3  
atof(PQparameterStatus(pgsql, server_version)) = 9.0) {
+#else
+   if (atof(PG_VERSION) = 9.0) {
+#endif
+   add_index_string(return_value, 2, pgsql_notify-extra, 
1);
+   }
}
if (result_type  PGSQL_ASSOC) {
add_assoc_string(return_value, message, 
pgsql_notify-relname, 1);
add_assoc_long(return_value, pid, pgsql_notify-be_pid);
+#if HAVE_PQPROTOCOLVERSION  HAVE_PQPARAMETERSTATUS
+   if (PQprotocolVersion(pgsql) = 3  
atof(PQparameterStatus(pgsql, server_version)) = 9.0) {
+#else
+   if (atof(PG_VERSION) = 9.0) {
+#endif
+   add_assoc_string(return_value, payload, 
pgsql_notify-extra, 1);
+   }
}
PQfreemem(pgsql_notify);
 }

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[PHP-CVS] svn: /php/php-src/trunk/ext/mysqlnd/ mysqlnd_auth.c

2011-01-27 Thread Andrey Hristov
andrey   Thu, 27 Jan 2011 17:30:29 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307798

Log:
fix a crash in new code

Changed paths:
U   php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c

Modified: php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c
===
--- php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c2011-01-27 16:02:30 UTC 
(rev 307797)
+++ php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c2011-01-27 17:30:29 UTC 
(rev 307798)
@@ -141,7 +141,9 @@
}

SET_NEW_MESSAGE(conn-last_message, conn-last_message_len, 
auth_resp_packet-message, auth_resp_packet-message_len, conn-persistent);
-   conn-charset = mysqlnd_find_charset_nr(auth_packet-charset_no);
+   if (use_full_blown_auth_packet == TRUE) {
+   conn-charset = 
mysqlnd_find_charset_nr(auth_packet-charset_no);
+   }
ret = PASS;
 end:
PACKET_FREE(change_auth_resp_packet);

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[PHP-CVS] svn: /php/php-src/trunk/ext/mysqlnd/ mysqlnd_auth.c

2011-01-27 Thread Andrey Hristov
andrey   Thu, 27 Jan 2011 18:51:12 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307799

Log:
a better habitat

Changed paths:
U   php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c

Modified: php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c
===
--- php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c2011-01-27 17:30:29 UTC 
(rev 307798)
+++ php/php-src/trunk/ext/mysqlnd/mysqlnd_auth.c2011-01-27 18:51:12 UTC 
(rev 307799)
@@ -110,6 +110,9 @@
goto end;
}
}
+   if (use_full_blown_auth_packet == TRUE) {
+   conn-charset = 
mysqlnd_find_charset_nr(auth_packet-charset_no);
+   }

if (FAIL == PACKET_READ(auth_resp_packet, conn) || 
auth_resp_packet-response_code = 0xFE) {
if (auth_resp_packet-response_code == 0xFE) {
@@ -141,9 +144,6 @@
}

SET_NEW_MESSAGE(conn-last_message, conn-last_message_len, 
auth_resp_packet-message, auth_resp_packet-message_len, conn-persistent);
-   if (use_full_blown_auth_packet == TRUE) {
-   conn-charset = 
mysqlnd_find_charset_nr(auth_packet-charset_no);
-   }
ret = PASS;
 end:
PACKET_FREE(change_auth_resp_packet);

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[PHP-CVS] svn: /php/php-src/ branches/PHP_5_3/ext/zip/tests/stream_meta_data.phpt trunk/ext/zip/tests/stream_meta_data.phpt

2011-01-27 Thread Adam Harvey
aharvey  Fri, 28 Jan 2011 03:55:34 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307805

Log:
Fix zip test.

Changed paths:
U   php/php-src/branches/PHP_5_3/ext/zip/tests/stream_meta_data.phpt
U   php/php-src/trunk/ext/zip/tests/stream_meta_data.phpt

Modified: php/php-src/branches/PHP_5_3/ext/zip/tests/stream_meta_data.phpt
===
--- php/php-src/branches/PHP_5_3/ext/zip/tests/stream_meta_data.phpt
2011-01-28 00:16:42 UTC (rev 307804)
+++ php/php-src/branches/PHP_5_3/ext/zip/tests/stream_meta_data.phpt
2011-01-28 03:55:34 UTC (rev 307805)
@@ -64,7 +64,7 @@
   [seekable]=
   bool(false)
   [uri]=
-  string(99) zip:///%stest_with_comment.zip#foo
+  string(%d) zip:///%stest_with_comment.zip#foo
   [timed_out]=
   bool(false)
   [blocked]=

Modified: php/php-src/trunk/ext/zip/tests/stream_meta_data.phpt
===
--- php/php-src/trunk/ext/zip/tests/stream_meta_data.phpt   2011-01-28 
00:16:42 UTC (rev 307804)
+++ php/php-src/trunk/ext/zip/tests/stream_meta_data.phpt   2011-01-28 
03:55:34 UTC (rev 307805)
@@ -64,7 +64,7 @@
   [seekable]=
   bool(false)
   [uri]=
-  string(99) zip:///%stest_with_comment.zip#foo
+  string(%d) zip:///%stest_with_comment.zip#foo
   [timed_out]=
   bool(false)
   [blocked]=

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[PHP-CVS] svn: /php/php-src/branches/PHP_5_3/ NEWS

2011-01-27 Thread Adam Harvey
aharvey  Fri, 28 Jan 2011 04:17:08 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307806

Log:
Fix NEWS typo.

Changed paths:
U   php/php-src/branches/PHP_5_3/NEWS

Modified: php/php-src/branches/PHP_5_3/NEWS
===
--- php/php-src/branches/PHP_5_3/NEWS   2011-01-28 03:55:34 UTC (rev 307805)
+++ php/php-src/branches/PHP_5_3/NEWS   2011-01-28 04:17:08 UTC (rev 307806)
@@ -144,7 +144,7 @@
 (Hannes)
   . Fixed bug #53603 (ZipArchive should quiet stat errors). (brad dot froehle 
at
 gmail dot com, Gustavo)
-  . Fixed bzg #53166 (Missing parameters in docs and reflection definition).
+  . Fixed bug #53166 (Missing parameters in docs and reflection definition).
 (Richard)

 06 Jan 2011, PHP 5.3.5

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[PHP-CVS] svn: /php/php-src/ branches/PHP_5_3/NEWS branches/PHP_5_3/ext/zip/php_zip.c branches/PHP_5_3/ext/zip/tests/bug53854.phpt trunk/UPGRADING trunk/ext/zip/php_zip.c trunk/ext/zip/tests/bug53854.

2011-01-27 Thread Adam Harvey
aharvey  Fri, 28 Jan 2011 04:19:40 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307807

Log:
Fixed bug #53854 (Missing constants for compression type). Patch by Richard
Quadling.

Bug: http://bugs.php.net/53854 (Assigned) Missing constants for compression 
type.
  
Changed paths:
U   php/php-src/branches/PHP_5_3/NEWS
U   php/php-src/branches/PHP_5_3/ext/zip/php_zip.c
A   php/php-src/branches/PHP_5_3/ext/zip/tests/bug53854.phpt
U   php/php-src/trunk/UPGRADING
U   php/php-src/trunk/ext/zip/php_zip.c
A   php/php-src/trunk/ext/zip/tests/bug53854.phpt

Modified: php/php-src/branches/PHP_5_3/NEWS
===
--- php/php-src/branches/PHP_5_3/NEWS   2011-01-28 04:17:08 UTC (rev 307806)
+++ php/php-src/branches/PHP_5_3/NEWS   2011-01-28 04:19:40 UTC (rev 307807)
@@ -146,6 +146,7 @@
 gmail dot com, Gustavo)
   . Fixed bug #53166 (Missing parameters in docs and reflection definition).
 (Richard)
+  . Fixed bug #53854 (Missing constants for compression type). (Richard, Adam)

 06 Jan 2011, PHP 5.3.5
 - Fixed Bug #53632 (infinite loop with x87 fpu). (CVE-2010-4645) (Scott,

Modified: php/php-src/branches/PHP_5_3/ext/zip/php_zip.c
===
--- php/php-src/branches/PHP_5_3/ext/zip/php_zip.c  2011-01-28 04:17:08 UTC 
(rev 307806)
+++ php/php-src/branches/PHP_5_3/ext/zip/php_zip.c  2011-01-28 04:19:40 UTC 
(rev 307807)
@@ -2754,6 +2754,12 @@
REGISTER_ZIP_CLASS_CONST_LONG(CM_DEFLATE, ZIP_CM_DEFLATE);
REGISTER_ZIP_CLASS_CONST_LONG(CM_DEFLATE64, ZIP_CM_DEFLATE64);
REGISTER_ZIP_CLASS_CONST_LONG(CM_PKWARE_IMPLODE, 
ZIP_CM_PKWARE_IMPLODE);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_BZIP2, ZIP_CM_BZIP2);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_LZMA, ZIP_CM_LZMA);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_TERSE, ZIP_CM_TERSE);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_LZ77, ZIP_CM_LZ77);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_WAVPACK, ZIP_CM_WAVPACK);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_PPMD, ZIP_CM_PPMD);

/* Error code */
REGISTER_ZIP_CLASS_CONST_LONG(ER_OK,  ZIP_ER_OK); 
/* N No error */

Added: php/php-src/branches/PHP_5_3/ext/zip/tests/bug53854.phpt
===
--- php/php-src/branches/PHP_5_3/ext/zip/tests/bug53854.phpt
(rev 0)
+++ php/php-src/branches/PHP_5_3/ext/zip/tests/bug53854.phpt2011-01-28 
04:19:40 UTC (rev 307807)
@@ -0,0 +1,44 @@
+--TEST--
+Bug #53854 (Missing constants for compression type)
+--SKIPIF--
+?php
+if(!extension_loaded('zip')) die('skip');
+?
+--FILE--
+?php
+
+var_dump(ZipArchive::CM_DEFAULT);
+var_dump(ZipArchive::CM_STORE);
+var_dump(ZipArchive::CM_SHRINK);
+var_dump(ZipArchive::CM_REDUCE_1);
+var_dump(ZipArchive::CM_REDUCE_2);
+var_dump(ZipArchive::CM_REDUCE_3);
+var_dump(ZipArchive::CM_REDUCE_4);
+var_dump(ZipArchive::CM_IMPLODE);
+var_dump(ZipArchive::CM_DEFLATE);
+var_dump(ZipArchive::CM_DEFLATE64);
+var_dump(ZipArchive::CM_PKWARE_IMPLODE);
+var_dump(ZipArchive::CM_BZIP2);
+var_dump(ZipArchive::CM_LZMA);
+var_dump(ZipArchive::CM_TERSE);
+var_dump(ZipArchive::CM_LZ77);
+var_dump(ZipArchive::CM_WAVPACK);
+var_dump(ZipArchive::CM_PPMD);
+--EXPECT--
+int(-1)
+int(0)
+int(1)
+int(2)
+int(3)
+int(4)
+int(5)
+int(6)
+int(8)
+int(9)
+int(10)
+int(12)
+int(14)
+int(18)
+int(19)
+int(97)
+int(98)

Modified: php/php-src/trunk/UPGRADING
===
--- php/php-src/trunk/UPGRADING 2011-01-28 04:17:08 UTC (rev 307806)
+++ php/php-src/trunk/UPGRADING 2011-01-28 04:19:40 UTC (rev 307807)
@@ -371,7 +371,12 @@

  i. New class constants

-   -
+   - ZipArchive::CM_BZIP2
+   - ZipArchive::CM_LZ77
+   - ZipArchive::CM_LZMA
+   - ZipArchive::CM_PPMD
+   - ZipArchive::CM_TERSE
+   - ZipArchive::CM_WAVPACK

  j. New Hash algorithms


Modified: php/php-src/trunk/ext/zip/php_zip.c
===
--- php/php-src/trunk/ext/zip/php_zip.c 2011-01-28 04:17:08 UTC (rev 307806)
+++ php/php-src/trunk/ext/zip/php_zip.c 2011-01-28 04:19:40 UTC (rev 307807)
@@ -2752,6 +2752,12 @@
REGISTER_ZIP_CLASS_CONST_LONG(CM_DEFLATE, ZIP_CM_DEFLATE);
REGISTER_ZIP_CLASS_CONST_LONG(CM_DEFLATE64, ZIP_CM_DEFLATE64);
REGISTER_ZIP_CLASS_CONST_LONG(CM_PKWARE_IMPLODE, 
ZIP_CM_PKWARE_IMPLODE);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_BZIP2, ZIP_CM_BZIP2);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_LZMA, ZIP_CM_LZMA);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_TERSE, ZIP_CM_TERSE);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_LZ77, ZIP_CM_LZ77);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_WAVPACK, ZIP_CM_WAVPACK);
+   REGISTER_ZIP_CLASS_CONST_LONG(CM_PPMD, ZIP_CM_PPMD);

/* Error code */

[PHP-CVS] svn: /php/php-src/branches/PHP_5_3/ NEWS

2011-01-27 Thread Adam Harvey
aharvey  Fri, 28 Jan 2011 04:30:12 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307808

Log:
Fix NEWS sorting.

Changed paths:
U   php/php-src/branches/PHP_5_3/NEWS

Modified: php/php-src/branches/PHP_5_3/NEWS
===
--- php/php-src/branches/PHP_5_3/NEWS   2011-01-28 04:19:40 UTC (rev 307807)
+++ php/php-src/branches/PHP_5_3/NEWS   2011-01-28 04:30:12 UTC (rev 307808)
@@ -138,14 +138,14 @@

 - Zip extension:
   . Added the filename into the return value of stream_get_meta_data(). 
(Hannes)
+  . Fixed bug #53166 (Missing parameters in docs and reflection definition).
+(Richard)
   . Fixed bug #53568 (swapped memset arguments in struct initialization).
 (crrodriguez at opensuse dot org)
   . Fixed bug #53579 (stream_get_contents() segfaults on ziparchive streams).
 (Hannes)
   . Fixed bug #53603 (ZipArchive should quiet stat errors). (brad dot froehle 
at
 gmail dot com, Gustavo)
-  . Fixed bug #53166 (Missing parameters in docs and reflection definition).
-(Richard)
   . Fixed bug #53854 (Missing constants for compression type). (Richard, Adam)

 06 Jan 2011, PHP 5.3.5

--- php/php-src/branches/PHP_5_3/ext/zip/php_zip.c	2011-01-27 09:57:01 UTC (rev 30)
+++ php/php-src/branches/PHP_5_3/ext/zip/php_zip.c	2011-01-27 11:47:24 UTC (rev 307778)
@@ -1688,7 +1688,7 @@
 }
 /* }}} */

-/* {{{ proto bool addGlob(string pattern[,int flags [, array options]])
+/* {{{ proto bool ZipArchive::addGlob(string pattern[,int flags [, array options]])
 Add files matching the glob pattern. See php's glob for the pattern syntax. */
 static ZIPARCHIVE_METHOD(addGlob)
 {
@@ -1696,7 +1696,7 @@
 }
 /* }}} */

-/* {{{ proto bool addPattern(string pattern[, string path [, array options]])
+/* {{{ proto bool ZipArchive::addPattern(string pattern[, string path [, array options]])
 Add files matching the pcre pattern. See php's pcre for the pattern syntax. */
 static ZIPARCHIVE_METHOD(addPattern)
 {
@@ -1925,7 +1925,7 @@
 }
 /* }}} */

-/* {{{ proto bool ZipArchive::setArchiveComment(string name, string comment)
+/* {{{ proto bool ZipArchive::setArchiveComment(string comment)
 Set or remove (NULL/'') the comment of the archive */
 static ZIPARCHIVE_METHOD(setArchiveComment)
 {
@@ -1951,7 +1951,7 @@
 }
 /* }}} */

 /* {{{ proto string ZipArchive::getArchiveComment()
 Returns the comment of an entry using its index */
 static ZIPARCHIVE_METHOD(getArchiveComment)
 {
@@ -2039,7 +2039,7 @@
 }
 /* }}} */

 /* {{{ proto string ZipArchive::getCommentName(string name)
 Returns the comment of an entry using its name */
 static ZIPARCHIVE_METHOD(getCommentName)
 {
@@ -2076,7 +2076,7 @@
 }
 /* }}} */

 /* {{{ proto string ZipArchive::getCommentIndex(int index)
 Returns the comment of an entry using its index */
 static ZIPARCHIVE_METHOD(getCommentIndex)
 {
@@ -2559,7 +2559,7 @@

 /* {{{ arginfo */
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_open, 0, 0, 1)
-	ZEND_ARG_INFO(0, source)
+	ZEND_ARG_INFO(0, filename)
 	ZEND_ARG_INFO(0, flags)
 ZEND_END_ARG_INFO()

@@ -2604,8 +2604,7 @@
 	ZEND_ARG_INFO(0, flags)
 ZEND_END_ARG_INFO()

-ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_setarchivecomment, 0, 0, 2)
-	ZEND_ARG_INFO(0, name)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_setarchivecomment, 0, 0, 1)
 	ZEND_ARG_INFO(0, comment)
 ZEND_END_ARG_INFO()

@@ -2616,10 +2615,12 @@

 ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_getcommentname, 0, 0, 1)
 	ZEND_ARG_INFO(0, name)
+	ZEND_ARG_INFO(0, flags)
 ZEND_END_ARG_INFO()

 ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_getcommentindex, 0, 0, 1)
 	ZEND_ARG_INFO(0, index)
+	ZEND_ARG_INFO(0, flags)
 ZEND_END_ARG_INFO()

 ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_renameindex, 0, 0, 2)
@@ -2657,6 +2658,15 @@
 	ZEND_ARG_INFO(0, flags)
 ZEND_END_ARG_INFO()

+ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_getarchivecomment, 0, 0, 0)
+	ZEND_ARG_INFO(0, flags)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_setcommentname, 0, 0, 2)
+	ZEND_ARG_INFO(0, name)
+	ZEND_ARG_INFO(0, comment)
+ZEND_END_ARG_INFO()
+
 ZEND_BEGIN_ARG_INFO_EX(arginfo_ziparchive_getstream, 0, 0, 1)
 	ZEND_ARG_INFO(0, entryname)
 ZEND_END_ARG_INFO()
@@ -2675,21 +2685,21 @@
 	ZIPARCHIVE_ME(renameIndex,			arginfo_ziparchive_renameindex, ZEND_ACC_PUBLIC)
 	ZIPARCHIVE_ME(renameName,			arginfo_ziparchive_renamename, ZEND_ACC_PUBLIC)
 	ZIPARCHIVE_ME(setArchiveComment,	arginfo_ziparchive_setarchivecomment, ZEND_ACC_PUBLIC)
-	ZIPARCHIVE_ME(getArchiveComment,	arginfo_ziparchive__void, ZEND_ACC_PUBLIC)
+	ZIPARCHIVE_ME(getArchiveComment,	arginfo_ziparchive_getarchivecomment, ZEND_ACC_PUBLIC)
 	ZIPARCHIVE_ME(setCommentIndex,		arginfo_ziparchive_setcommentindex, ZEND_ACC_PUBLIC)
-	ZIPARCHIVE_ME(setCommentName,		arginfo_ziparchive_setarchivecomment, 

[PHP-CVS] svn: /php/php-src/trunk/ext/mbstring/ mbstring.c

2011-01-27 Thread Scott MacVicar
scottmac Thu, 27 Jan 2011 11:47:31 +

Revision: http://svn.php.net/viewvc?view=revisionrevision=307779

Log:
Fix crash with mbstring, this probably isn't the correct behaviour but 272/276 
of the tests pass after this.

When mbstring.language is unset, it ends up being mbfl_no_language_neutral and 
there is no default when setting the encoding.

internal_encoding and current_internal_encoding then end up being null.

Changed paths:
U   php/php-src/trunk/ext/mbstring/mbstring.c

Modified: php/php-src/trunk/ext/mbstring/mbstring.c
===
--- php/php-src/trunk/ext/mbstring/mbstring.c   2011-01-27 11:47:24 UTC (rev 
307778)
+++ php/php-src/trunk/ext/mbstring/mbstring.c   2011-01-27 11:47:31 UTC (rev 
307779)
@@ -1252,7 +1252,7 @@
encoding = 
mbfl_no2encoding(mbfl_no_encoding_8859_9);
break;
default:
-   encoding = NULL;
+   encoding = 
@@ -1951,7 +1951,7 @@
 /* }}} */

-/* {{{ proto string ZipArchive::getArchiveComment()
+/* {{{ proto string ZipArchive::getArchiveComment([int flags])
 Returns the comment of an entry using its index */
 static ZIPARCHIVE_METHOD(getArchiveComment)
@@ -2039,7 +2039,7 @@
 /* }}} */

-/* {{{ proto string ZipArchive::getCommentName(string name)
+/* {{{ proto string ZipArchive::getCommentName(string name[, int flags])
 Returns the comment of an entry using its name */
 static ZIPARCHIVE_METHOD(getCommentName)
@@ -2076,7 +2076,7 @@
 /* }}} */

-/* {{{ proto string ZipArchive::getCommentIndex(int index)
+/* {{{ proto string ZipArchive::getCommentIndex(int index[, int flags])
 Returns the comment of an entry using its index */
 static ZIPARCHIVE_METHOD(getCommentIndex)
mbfl_no2encoding(mbfl_no_encoding_8859_1);
break;
}
}

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php